@@ -55,16 +55,12 @@ use vars qw(@ISA);
 require DBIx::HTMLView::Int;
 @ISA = qw(DBIx::HTMLView::Int);
 
-sub default_fmt {
-	my ($self, $kind)=@_;
-	if ($kind eq 'edit_html') {
-		return 	$self->fmt('view_html') . 
-			'<perl>if ($self->got_val) { return ' .
-				'"<input type=hidden name=\"".$self->name . "\" value=\"".$self->var("val")."\">"' . 
-			'} </perl>';
+sub edit_html {
+	my $self=shift;
+	if (defined $self->{'val'}) {
+		return $self->view_html.
+			'<input type=hidden name="'.$self->name.'" value="'.$self->val.'">';
+	} else {
+		return "";
 	}
-	return DBIx::HTMLView::Field::default_fmt(@_);
 }
-
-# FIXME: Make all Flds pass on ther $self vars like this
-sub sql_create {my $self=shift; $self->db->sql_type("Id",$self)}
